zms.standard.initutil

Package zms :: Module standard :: Class initutil |
[frames] | no frames]

# Class initutil

    object --+
             |
            initutil

Instance Methods
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature |
setConfProperty(self, key, value) |
getConfProperty(self, key, default=None) |
http_import(self, url, method='GET', auth=None, parse_qs=0, timeout=10, headers={'Accept': '*/*'}) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)